@@ -8,7 +8,7 @@ from collections import OrderedDict
 from dataclasses import dataclass
 from enum import Enum, auto
 from pathlib import Path
-from typing import Optional, Tuple, Any, List
+from typing import Dict, Optional, Tuple, Any, List
 
 DIR_ROOT = Path(__file__).resolve().parent
 
@@ -25,7 +25,7 @@ class Package:
     osName: Optional[str] = None
 
 
-Packages = OrderedDict[str, Package]
+Packages = Dict[str, Package]
 
 
 def pkg(*args, **kwargs) -> Tuple[str, Package]:
@@ -42,21 +42,22 @@ class Requirements:
 requirementsPkg = Requirements(
     filePath=makeReqFilePath(),
     packages=OrderedDict([
-        pkg('tendo', '0.2.15'),
-        pkg('psutil', '5.8.0'),
-        pkg('av', '8.0.3'),
-        pkg('pysubs2', '1.2.0'),
-        pkg('pycaption', '1.0.5'),
-        pkg('bottle', '0.12.19'),
-        pkg('zeroconf', '0.30.0'),
-        pkg('pychromecast', '9.2.0'),
-        pkg('dataclasses-json', '0.5.4'),
-        pkg('setproctitle', '1.2.2'),
-        pkg('pyqt5', '5.15.2'),
-
+        pkg('typing_extensions', '3.10.0', 'posix'),  # Exists because of MPRIS Server.
         pkg('mpris_server', '0.3.4', 'posix'),
 
         pkg('winrt', '1.0.21033.1', 'nt'),
+
+        pkg('tendo', '0.2.15'),
+        pkg('psutil', '5.9.0'),
+        pkg('av', '9.2.0'),
+        pkg('pysubs2', '1.4.2'),
+        pkg('pycaption', '2.0.8'),
+        pkg('bottle', '0.12.19'),
+        pkg('zeroconf', '0.30.0'),  # Exists because of PyChromecast.
+        pkg('pychromecast', '11.0.0'),
+        pkg('dataclasses-json', '0.5.7'),
+        pkg('setproctitle', '1.2.3'),
+        pkg('pyqt5', '5.15.6'),
     ]))
 
 requirementsDev = Requirements(
@@ -115,7 +116,7 @@ def generate(*args: Any) -> None:
     parser = argparse.ArgumentParser()
 
     parser.add_argument(Arg.Target(), help=Arg.Target.help(), choices=Target.all(), nargs='?', default=Target.Stable())
-    parser.add_argument(f'--{Arg.Pkg()}', help=Arg.Dev.help(), action="store_true")
+    parser.add_argument(f'--{Arg.Pkg()}', help=Arg.Pkg.help(), action="store_true")
     parser.add_argument(f'--{Arg.Dev()}', help=Arg.Dev.help(), action="store_true")
     parser.add_argument(f'--{Arg.Dist()}', help=Arg.Dist.help(), action="store_true")
 
