@@ -41,12 +41,14 @@ class MprisCastController(MprisAdapter):
             return f'/track/{get_dbus_name(name)}'
 
         title = self.get_stream_title()
+        contentUrl = self._castState.mediaState.contentUrl
+        contentUrl = contentUrl if contentUrl else None
 
         metadata = {
             'mpris:trackid': get_track_id(title),
             'mpris:length': castTimeToMprisTime(self._castState.mediaState.duration),
             'mpris:artUrl': self.get_art_url(),
-            'xesam:url': self._castState.mediaState.contentUrl,
+            'xesam:url': contentUrl,
             'xesam:title': title,
             'xesam:artist': [self._castState.deviceName],
         }
@@ -112,7 +114,7 @@ class MprisCastController(MprisAdapter):
         return PlayState.STOPPED
 
     def get_current_position(self) -> Microseconds:
-        return castTimeToMprisTime(self._castState.mediaState.adjustedPosition)
+        return castTimeToMprisTime(self._castState.mediaState.currentTime)
 
     def is_playlist(self) -> bool:
         return False
