@@ -8,13 +8,15 @@ from pathlib import Path
 from typing import Callable, Optional
 
 from kast.Services import Services
-from kast.interface.qt5.dialogs import dialogError, dialogQuestionOkCancel
 from kast.interface.qt5.service.BackgroundRunner import BackgroundRunner
 from kast.interface.qt5.service.InterfaceScheduler import InterfaceScheduler
 from kast.interface.qt5.service.UiEvent import Progress, UiEvent, UiState
 from kast.interface.qt5.service.UiStateService import UiStateService
+from kast.interface.qt5.utils.Schedulable import Callback, Schedulable
+from kast.interface.qt5.utils.dialogs import dialogError, dialogQuestionOkCancel
+from kast.interface.qt5.utils.schedule import backgroundTask, foregroundTask
 from kast.media.casting.CastException import CastException
-from kast.media.casting.CastState import DeviceName, CastState, CastMediaState
+from kast.media.casting.CastState import CastMediaState, CastState, DeviceName
 from kast.media.processing.MetaData import MetaData
 from kast.media.processing.SubtitleUtils import SubtitleException
 from kast.media.processing.SubtitlesSource import SubtitlesFromFile, SubtitlesFromStream
@@ -32,7 +34,7 @@ class StreamParams:
     subtitlesId: Optional[int] = None
 
 
-class MediaControlService(Loggable):
+class MediaControlService(Loggable, Schedulable):
 
     VideoOpenedCallback = Callable[[MetaData], None]
     TaskCallback = Callable[[], None]
@@ -44,6 +46,11 @@ class MediaControlService(Loggable):
         backgroundRunner: BackgroundRunner,
         uiStateService: UiStateService
     ) -> None:
+        super().__init__(
+            interfaceScheduler=interfaceScheduler,
+            backgroundRunner=backgroundRunner
+        )
+
         self._services = services
         self._interfaceScheduler = interfaceScheduler
         self._backgroundRunner = backgroundRunner
@@ -94,26 +101,29 @@ class MediaControlService(Loggable):
 
         self._uiStateService.dispatch(UiEvent(state=UiState.VideoProbe, progress=Progress(complete=False)))
 
-        def interfaceCallback(metaData: MetaData) -> None:
-            self._metaData = metaData
+        self._extractMetaData(filePath, callback)
 
-            self._subtitlesSourceList.clear()
-            for streamId in range(len(metaData.subtitleStreamLangs)):
-                self._subtitlesSourceList.append(SubtitlesFromStream(
-                    mediaProcessingService=self._services.mediaProcessingService,
-                    mediaFile=filePath,
-                    streamId=streamId
-                ))
+    @backgroundTask
+    def _extractMetaData(self, filePath: Path, callback: VideoOpenedCallback) -> None:
+        metaData = self._services.mediaProcessingService.extractMetaData(inputFile=filePath)
 
-            callback(metaData)
+        self._notifyMetaDataExtracted(metaData, filePath, callback)
 
-            self._uiStateService.dispatch(UiEvent(state=UiState.Idle))
+    @foregroundTask
+    def _notifyMetaDataExtracted(self, metaData: MetaData, filePath: Path, callback: VideoOpenedCallback) -> None:
+        self._metaData = metaData
 
-        def backgroundTask() -> None:
-            metaData = self._services.mediaProcessingService.extractMetaData(inputFile=filePath)
-            self._interfaceScheduler.schedule(lambda: interfaceCallback(metaData))
+        self._subtitlesSourceList.clear()
+        for streamId in range(len(metaData.subtitleStreamLangs)):
+            self._subtitlesSourceList.append(SubtitlesFromStream(
+                mediaProcessingService=self._services.mediaProcessingService,
+                mediaFile=filePath,
+                streamId=streamId
+            ))
 
-        self._backgroundRunner.execute(backgroundTask)
+        callback(metaData)
+
+        self._uiStateService.dispatch(UiEvent(state=UiState.Idle))
 
     def addSubtitles(self, filePath: Path) -> None:
         self._saveLastMediaDir(filePath)
@@ -137,8 +147,9 @@ class MediaControlService(Loggable):
 
         self._uiStateService.dispatch(UiEvent(state=UiState.Preprocessing, progress=Progress(complete=False)))
 
-        self._runInBackground(self._initTranscoding)
+        self._initTranscoding()
 
+    @backgroundTask
     def _initTranscoding(self) -> None:
         cancelEvent = threading.Event()
 
@@ -180,11 +191,12 @@ class MediaControlService(Loggable):
             f"resolution={transcoder.outputResolution}"
         )
         if transcoder.requireProcessing and self._lastTranscodeParams != transcoder.params:
-            self._runInForeground(lambda: self._confirmTranscoding(transcoder))
+            self._confirmTranscoding(transcoder)
             return
 
         self._startStreaming(transcoder.outputFile)
 
+    @foregroundTask
     def _confirmTranscoding(self, transcoder: Transcoder) -> None:
         message = "Selected media is not supported in it's current form. " \
             "Either because of a codec mismatch, too high resolution or not supported media container type. " \
@@ -211,8 +223,9 @@ class MediaControlService(Loggable):
             self._cancelAction()
             return
 
-        self._runInBackground(lambda: self._startTranscoding(transcoder))
+        self._startTranscoding(transcoder)
 
+    @backgroundTask
     def _startTranscoding(self, transcoder: Transcoder) -> None:
         if not transcoder.run():
             self._cancelAction()
@@ -220,8 +233,9 @@ class MediaControlService(Loggable):
 
         self._lastTranscodeParams = transcoder.params
 
-        self._runInForeground(lambda: self._confirmStreaming(transcoder.outputFile))
+        self._confirmStreaming(transcoder.outputFile)
 
+    @foregroundTask
     def _confirmStreaming(self, videoFile: Path) -> None:
         message = "Media processing finished!\n\nProceed with streaming?\n"
 
@@ -229,8 +243,9 @@ class MediaControlService(Loggable):
             self._cancelAction()
             return
 
-        self._runInBackground(lambda: self._startStreaming(videoFile))
+        self._startStreaming(videoFile)
 
+    @backgroundTask
     def _startStreaming(self, videoFile: Path) -> None:
         mediaContent = self._services.mediaServer.mediaContent
         mediaContent.movieFile = videoFile
@@ -255,19 +270,8 @@ class MediaControlService(Loggable):
     def _cancelAction(self) -> None:
         self._uiStateService.dispatch(UiEvent(state=UiState.Idle))
 
-    def _runInForeground(self, callback: TaskCallback) -> None:
-        self._interfaceScheduler.schedule(callback)
-
-    def _runInBackground(self, callback: TaskCallback) -> None:
-        def backgroundCallback() -> None:
-            try:
-                callback()
-            except (SubtitleException, CastException) as ex:
-                message = str(ex)  # Workaround for a 'free variable referenced before assignment' problem.
-                self.log.exception(ex)
-                self._reportError(message)
-
-        self._backgroundRunner.execute(backgroundCallback)
+    def _saveLastMediaDir(self, filePath) -> None:
+        self._services.settings.browseMediaDir = filePath.parent
 
     def _reportError(self, message) -> None:
         def interfaceCallback() -> None:
@@ -276,5 +280,10 @@ class MediaControlService(Loggable):
 
         self._interfaceScheduler.schedule(interfaceCallback)
 
-    def _saveLastMediaDir(self, filePath) -> None:
-        self._services.settings.browseMediaDir = filePath.parent
+    def backgroundTaskMiddleware(self, callback: Callback) -> None:
+        try:
+            callback()
+        except (SubtitleException, CastException) as ex:
+            message = str(ex)  # Workaround for a 'free variable referenced before assignment' problem.
+            self.log.exception(ex)
+            self._reportError(message)
