@@ -9,7 +9,7 @@ from typing import Optional
 from PyQt5.QtWidgets import QStyle, QWidget
 
 from kast.interface.qt5.UiServices import UiServices
-from kast.interface.qt5.dialogs import DialogQuestion
+from kast.interface.qt5.utils.dialogs import DialogQuestion
 from kast.interface.qt5.service.UiEvent import UiEvent, UiState
 from kast.interface.qt5.view.StatusBarView import Ui_StatusBarView
 from kast.interface.qt5.viewModel.ViewModelBase import ViewBase, ViewModelBase
