@@ -8,7 +8,7 @@ from typing import List, Optional
 from PyQt5.QtWidgets import QComboBox, QFileDialog, QStyle, QWidget
 
 from kast.interface.qt5.UiServices import UiServices
-from kast.interface.qt5.dialogs import dialogWarning
+from kast.interface.qt5.utils.dialogs import dialogWarning
 from kast.interface.qt5.service.UiEvent import Progress, UiEvent, UiState
 from kast.interface.qt5.view.VideoSettingsView import Ui_VideoSettingsView
 from kast.interface.qt5.viewModel.ViewModelBase import ViewBase, ViewModelBase
