@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 # Copyright by: P.J. Grochowski
 
-from typing import Optional
+from typing import Optional, Union
 
 from PyQt5.QtWidgets import QWidget
 
@@ -19,7 +19,9 @@ class ViewBase:
 
 class ViewModelBase:
 
-    def __init__(self, uiServices: UiServices, view: ViewBase) -> None:
+    View = Union[ViewBase, QWidget]
+
+    def __init__(self, uiServices: UiServices, view: View) -> None:
         self._uiServices = uiServices
         self.__view = view
 
@@ -32,5 +34,5 @@ class ViewModelBase:
         return self._uiServices
 
     @property
-    def view(self) -> QWidget:
+    def view(self) -> View:
         return self.__view
